==> plain_dev-0.0.1.tar.gz: plain_dev-0.0.1/plain/dev/precommit/cli.py <==
import os
import subprocess
import sys
from importlib.util import find_spec
from pathlib import Path

from plain.cli.print import print_event

from ..services import Services

try:
    import tomllib
except ModuleNotFoundError:
    import tomli as tomllib

import click


def install_git_hook():
    hook_path = os.path.join(".git", "hooks", "pre-commit")
    if os.path.exists(hook_path):
        print("pre-commit hook already exists")
    else:
        with open(hook_path, "w") as f:
            f.write(
                """#!/bin/sh
plain pre-commit"""
            )
        os.chmod(hook_path, 0o755)
        print("pre-commit hook installed")


@click.command()
@click.option("--install", is_flag=True)
def cli(install):
    """Git pre-commit checks"""
    if install:
        install_git_hook()
        return

    pyproject = Path("pyproject.toml")

    with Services():
        if pyproject.exists():
            with open(pyproject, "rb") as f:
                pyproject = tomllib.load(f)
            for name, data in (
                pyproject.get("tool", {})
                .get("plain", {})
                .get("pre-commit", {})
                .get("run", {})
            ).items():
                cmd = data["cmd"]
                print_event(f"Custom: {name} -> {cmd}")
                result = subprocess.run(cmd, shell=True)
                if result.returncode != 0:
                    sys.exit(result.returncode)

        # Run this first since it's probably the most likely to fail
        if find_spec("plain.code"):
            check_short("Running plain code checks", "plain", "code", "check")

        if Path("poetry.lock").exists():
            check_short("Checking poetry.lock", "poetry", "lock", "--check")

        if plain_db_connected():
            check_short(
                "Running preflight checks",
                "plain",
                "preflight",
                "--database",
                "default",
            )
            check_short(
                "Checking Plain migrations", "plain", "legacy", "migrate", "--check"
            )
            check_short(
                "Checking for Plain models missing migrations",
                "plain",
                "legacy",
                "makemigrations",
                "--dry-run",
                "--check",
            )
        else:
            check_short("Running Plain checks (without database)", "plain", "preflight")
            click.secho("--> Skipping migration checks", bold=True, fg="yellow")

        print_event("Running plain compile")
        result = subprocess.run(["plain", "compile"])
        if result.returncode != 0:
            sys.exit(result.returncode)

        if find_spec("plain.pytest"):
            print_event("Running tests")
            result = subprocess.run(["plain", "test"])
            if result.returncode != 0:
                sys.exit(result.returncode)


def plain_db_connected():
    result = subprocess.run(
        [
            "plain",
            "legacy",
            "showmigrations",
            "--skip-checks",
        ],
        stdout=subprocess.DEVNULL,
        stderr=subprocess.DEVNULL,
    )
    return result.returncode == 0


def check_short(message, *args):
    print_event(message, newline=False)
    result = subprocess.run(args, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
    if result.returncode != 0:
        click.secho("✘", fg="red")
        click.secho(result.stdout.decode("utf-8"))
        sys.exit(1)
    else:
        click.secho("✔", fg="green")

==> plain_dev-0.3.0.tar.gz: plain_dev-0.3.0/plain/dev/precommit/cli.py <==
import os
import subprocess
import sys
from importlib.util import find_spec
from pathlib import Path

from plain.cli.print import print_event

from ..services import Services

try:
    import tomllib
except ModuleNotFoundError:
    import tomli as tomllib

import click


def install_git_hook():
    hook_path = os.path.join(".git", "hooks", "pre-commit")
    if os.path.exists(hook_path):
        print("pre-commit hook already exists")
    else:
        with open(hook_path, "w") as f:
            f.write(
                """#!/bin/sh
plain pre-commit"""
            )
        os.chmod(hook_path, 0o755)
        print("pre-commit hook installed")


@click.command()
@click.option("--install", is_flag=True)
def cli(install):
    """Git pre-commit checks"""
    if install:
        install_git_hook()
        return

    pyproject = Path("pyproject.toml")

    with Services():
        if pyproject.exists():
            with open(pyproject, "rb") as f:
                pyproject = tomllib.load(f)
            for name, data in (
                pyproject.get("tool", {})
                .get("plain", {})
                .get("pre-commit", {})
                .get("run", {})
            ).items():
                cmd = data["cmd"]
                print_event(f"Custom: {name} -> {cmd}")
                result = subprocess.run(cmd, shell=True)
                if result.returncode != 0:
                    sys.exit(result.returncode)

        # Run this first since it's probably the most likely to fail
        if find_spec("plain.code"):
            check_short("Running plain code checks", "plain", "code", "check")

        if Path("poetry.lock").exists():
            check_short("Checking poetry.lock", "poetry", "check", "--lock")

        if plain_db_connected():
            check_short(
                "Running preflight checks",
                "plain",
                "preflight",
                "--database",
                "default",
            )
            check_short("Checking Plain migrations", "plain", "migrate", "--check")
            check_short(
                "Checking for Plain models missing migrations",
                "plain",
                "makemigrations",
                "--dry-run",
                "--check",
            )
        else:
            check_short("Running Plain checks (without database)", "plain", "preflight")
            click.secho("--> Skipping migration checks", bold=True, fg="yellow")

        print_event("Running plain compile")
        result = subprocess.run(["plain", "compile"])
        if result.returncode != 0:
            sys.exit(result.returncode)

        if find_spec("plain.pytest"):
            print_event("Running tests")
            result = subprocess.run(["plain", "test"])
            if result.returncode != 0:
                sys.exit(result.returncode)


def plain_db_connected():
    result = subprocess.run(
        [
            "plain",
            "models",
            "showmigrations",
            "--skip-checks",
        ],
        stdout=subprocess.DEVNULL,
        stderr=subprocess.DEVNULL,
    )
    return result.returncode == 0


def check_short(message, *args):
    print_event(message, newline=False)
    result = subprocess.run(args, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
    if result.returncode != 0:
        click.secho("✘", fg="red")
        click.secho(result.stdout.decode("utf-8"))
        sys.exit(1)
    else:
        click.secho("✔", fg="green")
